# s3-manager

Библиотека для основных операций с s3-хранилищем


## Installation

Установка из PyPi

```commandline
pip install s3-manager
```

## Configuration


Для конфигурации необходимо добавить в .env файл следующие переменные с вашими значениями


```
APP_S3_SECRET_KEY=your_secret_key
APP_S3_ACCESS_KEY=your_access_key
APP_S3_BUCKET=your_bucket
APP_S3_ENDPOINT=http://localhost:9000
```

## License
Распространяется под лицензией MIT.

Поддержка
Issues: GitLab Issues

Вопросы и обсуждения: Открывайте issue для багов и запросов функций

Проект в активной разработке. API может меняться 